==> ci-auto-update-phpboost-6.0.3.zip: phpboost_ynh/README_eu.md <==
<!--
Ohart ongi: README hau automatikoki sortu da <https://github.com/YunoHost/apps/tree/master/tools/readme_generator>ri esker
EZ editatu eskuz.
-->

# PHPBoost YunoHost-erako

[![Integrazio maila](https://dash.yunohost.org/integration/phpboost.svg)](https://dash.yunohost.org/appci/app/phpboost) ![Funtzionamendu egoera](https://ci-apps.yunohost.org/ci/badges/phpboost.status.svg) ![Mantentze egoera](https://ci-apps.yunohost.org/ci/badges/phpboost.maintain.svg)

[![Instalatu PHPBoost YunoHost-ekin](https://install-app.yunohost.org/install-with-yunohost.svg)](https://install-app.yunohost.org/?app=phpboost)

*[Irakurri README hau beste hizkuntzatan.](./ALL_README.md)*

> *Pakete honek PHPBoost YunoHost zerbitzari batean azkar eta zailtasunik gabe instalatzea ahalbidetzen dizu.*  
> *YunoHost ez baduzu, kontsultatu [gida](https://yunohost.org/install) nola instalatu ikasteko.*

## Aurreikuspena

PHPBoost allows everyone to create his own website without any particular knowledge required in webmastering.

**Paketatutako bertsioa:** 6.0.3~ynh1

**Demoa:** <https://demo.phpboost.com/>

## Pantaila-argazkiak

![PHPBoost(r)en pantaila-argazkia](./doc/screenshots/screenshot.png)

## Dokumentazioa eta baliabideak

- Aplikazioaren webgune ofiziala: <https://www.phpboost.com/>
- Administratzaileen dokumentazio ofiziala: <https://www.phpboost.com/wiki/wiki.php>
- Jatorrizko aplikazioaren kode-gordailua: <https://github.com/PHPBoost/PHPBoost>
- YunoHost Denda: <https://apps.yunohost.org/app/phpboost>
- Eman errore baten berri: <https://github.com/YunoHost-Apps/phpboost_ynh/issues>

## Garatzaileentzako informazioa

Bidali `pull request`a [`testing` abarrera](https://github.com/YunoHost-Apps/phpboost_ynh/tree/testing).

`testing` abarra probatzeko, ondorengoa egin:

```bash
sudo yunohost app install https://github.com/YunoHost-Apps/phpboost_ynh/tree/testing --debug
edo
sudo yunohost app upgrade phpboost -u https://github.com/YunoHost-Apps/phpboost_ynh/tree/testing --debug
```

**Informazio gehiago aplikazioaren paketatzeari buruz:** <https://yunohost.org/packaging_apps>

==> ci-auto-update-phpboost-6.0.4.zip: phpboost_ynh/README_eu.md <==
<!--
Ohart ongi: README hau automatikoki sortu da <https://github.com/YunoHost/apps/tree/master/tools/readme_generator>ri esker
EZ editatu eskuz.
-->

# PHPBoost YunoHost-erako

[![Integrazio maila](https://dash.yunohost.org/integration/phpboost.svg)](https://ci-apps.yunohost.org/ci/apps/phpboost/) ![Funtzionamendu egoera](https://ci-apps.yunohost.org/ci/badges/phpboost.status.svg) ![Mantentze egoera](https://ci-apps.yunohost.org/ci/badges/phpboost.maintain.svg)

[![Instalatu PHPBoost YunoHost-ekin](https://install-app.yunohost.org/install-with-yunohost.svg)](https://install-app.yunohost.org/?app=phpboost)

*[Irakurri README hau beste hizkuntzatan.](./ALL_README.md)*

> *Pakete honek PHPBoost YunoHost zerbitzari batean azkar eta zailtasunik gabe instalatzea ahalbidetzen dizu.*  
> *YunoHost ez baduzu, kontsultatu [gida](https://yunohost.org/install) nola instalatu ikasteko.*

## Aurreikuspena

PHPBoost allows everyone to create his own website without any particular knowledge required in webmastering.

**Paketatutako bertsioa:** phpboost-6.0.4~ynh1

**Demoa:** <https://demo.phpboost.com/>

## Pantaila-argazkiak

![PHPBoost(r)en pantaila-argazkia](./doc/screenshots/screenshot.png)

## Dokumentazioa eta baliabideak

- Aplikazioaren webgune ofiziala: <https://www.phpboost.com/>
- Administratzaileen dokumentazio ofiziala: <https://www.phpboost.com/wiki/wiki.php>
- Jatorrizko aplikazioaren kode-gordailua: <https://github.com/PHPBoost/PHPBoost>
- YunoHost Denda: <https://apps.yunohost.org/app/phpboost>
- Eman errore baten berri: <https://github.com/YunoHost-Apps/phpboost_ynh/issues>

## Garatzaileentzako informazioa

Bidali `pull request`a [`testing` abarrera](https://github.com/YunoHost-Apps/phpboost_ynh/tree/testing).

`testing` abarra probatzeko, ondorengoa egin:

```bash
sudo yunohost app install https://github.com/YunoHost-Apps/phpboost_ynh/tree/testing --debug
edo
sudo yunohost app upgrade phpboost -u https://github.com/YunoHost-Apps/phpboost_ynh/tree/testing --debug
```

**Informazio gehiago aplikazioaren paketatzeari buruz:** <https://yunohost.org/packaging_apps>
